==> horde-2.0.tar.gz: horde-2.0/lib/SessionCache.php <==
<?php
// $Horde: horde/lib/SessionCache.php,v 1.5.2.2 2001/12/16 05:53:50 chuck Exp $

/**
 * The maximum number of objects that the session cache will hold.
 * @const SESSION_CACHE_SIZE
 */
define('SESSION_CACHE_SIZE', 20);


/**
 * SessionCache:: provides an API for storing a limited number of
 * pieces of data intended to have a short lifetime in a user's
 * session.
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.5.2.2 $
 * @since Horde 1.3
 * @package horde
 */
class SessionCache {

    /**
     * Stores a new object in the session cache.
     *
     * @param mixed $object     The object to store in the session cache.
     *
     * @return string           The MD5 string representing the object's ID.
     */
    function putObject($object)
    {
        $store = serialize($object);
        $objectID = md5($store);
        if (!isset($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'])) {
            global $hordeObjectCache;
            $hordeObjectCache = array();
            $hordeObjectCache[$objectID] = $store;
            session_register('hordeObjectCache');
            $GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'] = &$hordeObjectCache;
        } else {
            /* Prune the cache if there are more than $cacheSize items in it. */
            if (count($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache']) >= SESSION_CACHE_SIZE) {
                array_shift($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache']);
            }
            $GLOBALS['hordeObjectCache'] = &$GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'];
            $GLOBALS['hordeObjectCache'][$objectID] = $store;
        }
        
        return $objectID;
    }
    
    /**
     * Retrives an object from the session cache.
     *
     * @param string $objectID  The ID of the object to retrieve.
     *
     * @return mixed            The requested object, or false on failure.
     */
    function getObject($objectID)
    {
        if (!isset($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'][$objectID])) {
            return false;
        }
        
        return unserialize($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'][$objectID]);
    }
    
}
?>

==> horde-2.1.tar.gz: horde-2.1/lib/SessionCache.php <==
<?php
// $Horde: horde/lib/SessionCache.php,v 1.5.2.3 2002/04/05 01:24:23 jon Exp $

/**
 * The maximum number of objects that the session cache will hold.
 * @const SESSION_CACHE_SIZE
 */
define('SESSION_CACHE_SIZE', 20);


/**
 * SessionCache:: provides an API for storing a limited number of
 * pieces of data intended to have a short lifetime in a user's
 * session.
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.5.2.3 $
 * @since Horde 1.3
 * @package horde
 */
class SessionCache {

    /**
     * Stores a new object in the session cache.
     *
     * @param mixed $object     The object to store in the session cache.
     *
     * @return string           The MD5 string representing the object's ID.
     */
    function putObject($object)
    {
        $store = serialize($object);
        $objectID = md5($store);
        if (!isset($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'])) {
            global $hordeObjectCache;
            $hordeObjectCache = array();
            $hordeObjectCache[$objectID] = $store;
            session_register('hordeObjectCache');
            $GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'] = &$hordeObjectCache;
        } else {
            /* Prune the cache if there are more than $cacheSize items in it. */
            if (count($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache']) >= SESSION_CACHE_SIZE) {
                array_shift($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache']);
            }
            $GLOBALS['hordeObjectCache'] = &$GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'];
            $GLOBALS['hordeObjectCache'][$objectID] = $store;
        }

        return $objectID;
    }

    /**
     * Retrives an object from the session cache.
     *
     * @param string $objectID  The ID of the object to retrieve.
     *
     * @return mixed            The requested object, or false on failure.
     */
    function getObject($objectID)
    {
        if (!isset($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'][$objectID])) {
            return false;
        }

        return unserialize($GLOBALS['HTTP_SESSION_VARS']['hordeObjectCache'][$objectID]);
    }

}
?>
